@@ -70,58 +70,58 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
     """
 
     def paginate(
         self,
         *,
-        TableName: str = None,
-        TimeRangeLowerBound: Union[datetime, str] = None,
-        TimeRangeUpperBound: Union[datetime, str] = None,
-        BackupType: BackupTypeFilterType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        TableName: str = ...,
+        TimeRangeLowerBound: Union[datetime, str] = ...,
+        TimeRangeUpperBound: Union[datetime, str] = ...,
+        BackupType: BackupTypeFilterType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBackupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTablesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
     """
 
     def paginate(
-        self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTagsOfResourceOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
     """
 
@@ -129,19 +129,19 @@ class QueryPaginator(Boto3Paginator):
         self,
         *,
         TableName: str,
-        IndexName: str = None,
-        Select: SelectType = None,
-        AttributesToGet: Sequence[str] = None,
-        ConsistentRead: bool = None,
-        KeyConditions: Mapping[str, "ConditionTypeDef"] = None,
-        QueryFilter: Mapping[str, "ConditionTypeDef"] = None,
-        ConditionalOperator: ConditionalOperatorType = None,
-        ScanIndexForward: bool = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ProjectionExpression: str = None,
-        FilterExpression: str = None,
-        KeyConditionExpression: str = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        IndexName: str = ...,
+        Select: SelectType = ...,
+        AttributesToGet: Sequence[str] = ...,
+        ConsistentRead: bool = ...,
+        KeyConditions: Mapping[str, "ConditionTypeDef"] = ...,
+        QueryFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
+        ScanIndexForward: bool = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ProjectionExpression: str = ...,
+        FilterExpression: str = ...,
+        KeyConditionExpression: str = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -160,18 +160,18 @@ class QueryPaginator(Boto3Paginator):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        ] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[QueryOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
     """
 
@@ -179,17 +179,17 @@ class ScanPaginator(Boto3Paginator):
         self,
         *,
         TableName: str,
-        IndexName: str = None,
-        AttributesToGet: Sequence[str] = None,
-        Select: SelectType = None,
-        ScanFilter: Mapping[str, "ConditionTypeDef"] = None,
-        ConditionalOperator: ConditionalOperatorType = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        TotalSegments: int = None,
-        Segment: int = None,
-        ProjectionExpression: str = None,
-        FilterExpression: str = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        IndexName: str = ...,
+        AttributesToGet: Sequence[str] = ...,
+        Select: SelectType = ...,
+        ScanFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        TotalSegments: int = ...,
+        Segment: int = ...,
+        ProjectionExpression: str = ...,
+        FilterExpression: str = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -208,11 +208,11 @@ class ScanPaginator(Boto3Paginator):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None,
-        ConsistentRead: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        ] = ...,
+        ConsistentRead: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ScanOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
         """
