@@ -67,7 +67,7 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#serviceresourcetablescollection)
     """
 
@@ -77,7 +77,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
         """
 
     def filter(  # type: ignore
-        self, *, ExclusiveStartTableName: str = None, Limit: int = None
+        self, *, ExclusiveStartTableName: str = ..., Limit: int = ...
     ) -> "ServiceResourceTablesCollection":
         """
         Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
@@ -106,7 +106,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
     """
 
@@ -137,7 +137,7 @@ class Table(Boto3ServiceResource):
         """
         Create a batch writer object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch_writer-method)
         """
 
@@ -145,7 +145,7 @@ class Table(Boto3ServiceResource):
         """
         The `DeleteTable` operation deletes a table and all of its items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-method)
         """
 
@@ -171,13 +171,13 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = None,
-        ConditionalOperator: ConditionalOperatorType = None,
-        ReturnValues: ReturnValueType = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
-        ConditionExpression: str = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
+        ReturnValues: ReturnValueType = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
+        ConditionExpression: str = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -196,12 +196,12 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None
+        ] = ...
     ) -> DeleteItemOutputTypeDef:
         """
         Deletes a single item in a table by primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete_item-method)
         """
 
@@ -209,7 +209,7 @@ class Table(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_available_subresources-method)
         """
 
@@ -235,17 +235,17 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        AttributesToGet: Sequence[str] = None,
-        ConsistentRead: bool = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ProjectionExpression: str = None,
-        ExpressionAttributeNames: Mapping[str, str] = None
+        AttributesToGet: Sequence[str] = ...,
+        ConsistentRead: bool = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ProjectionExpression: str = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...
     ) -> GetItemOutputTypeDef:
         """
         The `GetItem` operation returns a set of attributes for the item with the given
         primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_item-method)
         """
 
@@ -254,7 +254,7 @@ class Table(Boto3ServiceResource):
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
         Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableload-method)
         """
 
@@ -280,13 +280,13 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = None,
-        ReturnValues: ReturnValueType = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
-        ConditionalOperator: ConditionalOperatorType = None,
-        ConditionExpression: str = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        ReturnValues: ReturnValueType = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
+        ConditionExpression: str = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -305,27 +305,27 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None
+        ] = ...
     ) -> PutItemOutputTypeDef:
         """
         Creates a new item, or replaces an old item with a new item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput_item-method)
         """
 
     def query(
         self,
         *,
-        IndexName: str = None,
-        Select: SelectType = None,
-        AttributesToGet: Sequence[str] = None,
-        Limit: int = None,
-        ConsistentRead: bool = None,
-        KeyConditions: Mapping[str, "ConditionTypeDef"] = None,
-        QueryFilter: Mapping[str, "ConditionTypeDef"] = None,
-        ConditionalOperator: ConditionalOperatorType = None,
-        ScanIndexForward: bool = None,
+        IndexName: str = ...,
+        Select: SelectType = ...,
+        AttributesToGet: Sequence[str] = ...,
+        Limit: int = ...,
+        ConsistentRead: bool = ...,
+        KeyConditions: Mapping[str, "ConditionTypeDef"] = ...,
+        QueryFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
+        ScanIndexForward: bool = ...,
         ExclusiveStartKey: Mapping[
             str,
             Union[
@@ -344,12 +344,12 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ProjectionExpression: str = None,
-        FilterExpression: Union[str, ConditionBase] = None,
-        KeyConditionExpression: Union[str, ConditionBase] = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        ] = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ProjectionExpression: str = ...,
+        FilterExpression: Union[str, ConditionBase] = ...,
+        KeyConditionExpression: Union[str, ConditionBase] = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -368,12 +368,12 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None
+        ] = ...
     ) -> QueryOutputTypeDef:
         """
         The `Query` operation finds items based on primary key values.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequery-method)
         """
 
@@ -382,19 +382,19 @@ class Table(Boto3ServiceResource):
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
         Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereload-method)
         """
 
     def scan(
         self,
         *,
-        IndexName: str = None,
-        AttributesToGet: Sequence[str] = None,
-        Limit: int = None,
-        Select: SelectType = None,
-        ScanFilter: Mapping[str, "ConditionTypeDef"] = None,
-        ConditionalOperator: ConditionalOperatorType = None,
+        IndexName: str = ...,
+        AttributesToGet: Sequence[str] = ...,
+        Limit: int = ...,
+        Select: SelectType = ...,
+        ScanFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
         ExclusiveStartKey: Mapping[
             str,
             Union[
@@ -413,13 +413,13 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        TotalSegments: int = None,
-        Segment: int = None,
-        ProjectionExpression: str = None,
-        FilterExpression: Union[str, ConditionBase] = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        ] = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        TotalSegments: int = ...,
+        Segment: int = ...,
+        ProjectionExpression: str = ...,
+        FilterExpression: Union[str, ConditionBase] = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -438,33 +438,33 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None,
-        ConsistentRead: bool = None
+        ] = ...,
+        ConsistentRead: bool = ...
     ) -> ScanOutputTypeDef:
         """
         The `Scan` operation returns one or more items and item attributes by accessing
         every item in a table or a secondary index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescan-method)
         """
 
     def update(
         self,
         *,
-        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"] = None,
-        BillingMode: BillingModeType = None,
-        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
-        GlobalSecondaryIndexUpdates: Sequence["GlobalSecondaryIndexUpdateTypeDef"] = None,
-        StreamSpecification: "StreamSpecificationTypeDef" = None,
-        SSESpecification: "SSESpecificationTypeDef" = None,
-        ReplicaUpdates: Sequence["ReplicationGroupUpdateTypeDef"] = None
+        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"] = ...,
+        BillingMode: BillingModeType = ...,
+        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = ...,
+        GlobalSecondaryIndexUpdates: Sequence["GlobalSecondaryIndexUpdateTypeDef"] = ...,
+        StreamSpecification: "StreamSpecificationTypeDef" = ...,
+        SSESpecification: "SSESpecificationTypeDef" = ...,
+        ReplicaUpdates: Sequence["ReplicationGroupUpdateTypeDef"] = ...
     ) -> "_Table":
         """
         Modifies the provisioned throughput settings, global secondary indexes, or
         DynamoDB Streams settings for a given table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-method)
         """
 
@@ -490,15 +490,15 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        AttributeUpdates: Mapping[str, "AttributeValueUpdateTypeDef"] = None,
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = None,
-        ConditionalOperator: ConditionalOperatorType = None,
-        ReturnValues: ReturnValueType = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
-        UpdateExpression: str = None,
-        ConditionExpression: str = None,
-        ExpressionAttributeNames: Mapping[str, str] = None,
+        AttributeUpdates: Mapping[str, "AttributeValueUpdateTypeDef"] = ...,
+        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        ConditionalOperator: ConditionalOperatorType = ...,
+        ReturnValues: ReturnValueType = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
+        UpdateExpression: str = ...,
+        ConditionExpression: str = ...,
+        ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
             Union[
@@ -517,13 +517,13 @@ class Table(Boto3ServiceResource):
                 Mapping[str, Any],
                 None,
             ],
-        ] = None
+        ] = ...
     ) -> UpdateItemOutputTypeDef:
         """
         Edits an existing item's attributes, or adds a new item to the table if it does
         not already exist.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate_item-method)
         """
 
@@ -531,7 +531,7 @@ class Table(Boto3ServiceResource):
         """
         Waits until this Table is exists.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_exists-method)
         """
 
@@ -539,7 +539,7 @@ class Table(Boto3ServiceResource):
         """
         Waits until this Table is not exists.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_not_exists-method)
         """
 
@@ -553,7 +553,7 @@ class DynamoDBResourceMeta(ResourceMeta):
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
     """
 
@@ -564,7 +564,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         """
         Creates a Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetable-method)
         """
 
@@ -572,13 +572,13 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         self,
         *,
         RequestItems: Mapping[str, "KeysAndAttributesTypeDef"],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> BatchGetItemOutputTypeDef:
         """
         The `BatchGetItem` operation returns the attributes of one or more items from
         one or more tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_get_item-method)
         """
 
@@ -586,14 +586,14 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         self,
         *,
         RequestItems: Mapping[str, Sequence["WriteRequestTypeDef"]],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...
     ) -> BatchWriteItemOutputTypeDef:
         """
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
         tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_write_item-method)
         """
 
@@ -603,18 +603,18 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"],
         TableName: str,
         KeySchema: Sequence["KeySchemaElementTypeDef"],
-        LocalSecondaryIndexes: Sequence["LocalSecondaryIndexTypeDef"] = None,
-        GlobalSecondaryIndexes: Sequence["GlobalSecondaryIndexTypeDef"] = None,
-        BillingMode: BillingModeType = None,
-        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
-        StreamSpecification: "StreamSpecificationTypeDef" = None,
-        SSESpecification: "SSESpecificationTypeDef" = None,
-        Tags: Sequence["TagTypeDef"] = None
+        LocalSecondaryIndexes: Sequence["LocalSecondaryIndexTypeDef"] = ...,
+        GlobalSecondaryIndexes: Sequence["GlobalSecondaryIndexTypeDef"] = ...,
+        BillingMode: BillingModeType = ...,
+        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = ...,
+        StreamSpecification: "StreamSpecificationTypeDef" = ...,
+        SSESpecification: "SSESpecificationTypeDef" = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> _Table:
         """
         The `CreateTable` operation adds a new table to your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate_table-method)
         """
 
@@ -622,6 +622,6 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget_available_subresources-method)
         """
