@@ -29,25 +29,25 @@ __all__ = ("TableExistsWaiter", "TableNotExistsWaiter")
 
 class TableExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
     """
 
-    def wait(self, *, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
+    def wait(self, *, TableName: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
         """
 
 
 class TableNotExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
     """
 
-    def wait(self, *, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
+    def wait(self, *, TableName: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
         """
